@@ -13,13 +13,13 @@ function (keys, r.mat, correct = TRUE,digits=2)
     key.count <- diag(t(keys) %*% keys)    #how many items in each cluster?
     if (correct) {
                   cluster.correct <- diag((key.count/(key.count - 1)))
-                   for (i in 1:ncol(keys)) {
-                         if (key.count[i]==1) {   #fix the case of 1 item keys
+                   for (i in 1:dim(keys)[2]) {
+                         if (key.count[i]<2 ) {   #fix the case of 1 item keys
                    	     cluster.correct[i,i] <- 1
                    	} else { cluster.correct[i,i] <- key.count[i]/(key.count[i]-1)
-                   	item.covar[,i] <- item.covar[,i] - keys[,i]} 
+                   	item.covar[,i] <- item.covar[,i] - keys[,i]} #subtract the variance of the item
                    }   #i loop
-                   correction.factor <- keys %*% cluster.correct
+                   correction.factor <- keys %*% cluster.correct #put back average correlation for the item if it loads on the key
                    correction.factor[ correction.factor < 1] <- 1
                   item.covar <- item.covar * correction.factor
                   }
@@ -28,6 +28,7 @@ function (keys, r.mat, correct = TRUE,digits=2)
     ident.sd <- diag(sd.inv, ncol = length(sd.inv))
     c.loading <-  item.covar %*% ident.sd
     c.correl <- ident.sd %*% covar %*% ident.sd
+    p.loading <- c.loading %*% solve(c.correl)
     
      c.loading[abs(c.loading)  > 99999] <- NA
       c.correl[abs(c.correl) > 99999] <- NA
@@ -37,13 +38,15 @@ function (keys, r.mat, correct = TRUE,digits=2)
     key.alpha <- ((var - key.count)/var) * (key.count/(key.count - 1))
     key.alpha[is.nan(key.alpha)] <- 1
     key.alpha[!is.finite(key.alpha)] <- 1
+    key.av.r <- key.alpha/(key.count - key.alpha*(key.count-1))  #alpha 1 = average r
     colnames(c.loading) <- colnames(keys)
+     colnames(p.loading) <- colnames(keys)
     colnames(c.correl) <- colnames(keys)
     rownames(c.correl) <- colnames(keys)
     rownames(c.loading) <- rownames(r.mat)
     
     if( ncol(keys) >1)  {cluster.corrected <- correct.cor(c.correl, t(key.alpha))} else {cluster.corrected <- c.correl}
     
-    return(list(loadings=round(c.loading,digits), cor=round(c.correl,digits),corrected=round(cluster.corrected,digits), sd = round(sqrt(var),digits), alpha = round(key.alpha,digits),
+    return(list(loadings=round(c.loading,digits),pattern=round(p.loading,digits), cor=round(c.correl,digits),corrected=round(cluster.corrected,digits), sd = round(sqrt(var),digits), alpha = round(key.alpha,digits),av.r = round(key.av.r,2),
             size = key.count))
     }
