@@ -1,6 +1,7 @@
 "multi.hist" <-
 function(x,nrow=NULL,ncol=NULL,density=TRUE,main="Histogram, Density, and Normal Fit") {
 nvar <- dim(x)[2]  #number of variables
+     if(!density & (main == "Histogram, Density, and Normal Fit")) main = "Histogram" 
      nsize=ceiling(sqrt(nvar))   #size of graphic
      if(is.null(nrow) ) nrow <-nsize
      if(is.null(ncol)) ncol  <- ceiling(nvar/nsize )
@@ -10,7 +11,7 @@ nvar <- dim(x)[2]  #number of variables
      for (i in 1:nvar) {
     	 xlab=names(x)[i]                #get the names for the variables
     	if(density) {histo.density(x[,i],xlab=xlab,main=main)} else {
-    				hist(x[,i],main=name,xlab=xlab)}
+    				hist(x[,i],main=main,xlab=xlab)}
     }  #draw the histograms for each variable
      on.exit(par(old.par))   #set the graphic parameters back to the original
      }
