@@ -1,5 +1,5 @@
 "omega" <-
-function(m,nfactors=3,pc="mle",key=NULL,flip=TRUE, digits=NULL,...) {
+function(m,nfactors=3,pc="mle",key=NULL,flip=TRUE, digits=2,title="Omega",sl=TRUE,labels=NULL, plot=TRUE,rotate="oblimin",...) {
       #m is a correlation matrix, or if not, the correlation matrix is found
       #nfactors is the number of factors to extract
       #key allows items to be reversed scored  if desired
@@ -19,7 +19,7 @@ function(m,nfactors=3,pc="mle",key=NULL,flip=TRUE, digits=NULL,...) {
              colnames(m) <- rownames(m) <- m.names
       if ((nvar < 6) && (pc=="mle") ) {warning(paste("3 factors is too many for ",nvar," variables using mle.  Using pa instead",sep=""))
        pc <- "pa"} 
-       gf<-schmid(m,nfactors,pc,digits, ...)
+       gf<-schmid(m,nfactors,pc,digits,rotate=rotate, ...)
 
       Vt <- sum(m)   #find the total variance in the scale
       Vitem <-sum(diag(m)) #
@@ -36,7 +36,7 @@ function(m,nfactors=3,pc="mle",key=NULL,flip=TRUE, digits=NULL,...) {
              m.names <- paste(m.names,signkey,sep="")
              colnames(m) <- rownames(m) <- m.names
              
-             gf<-schmid(m,nfactors,pc,digits,...)
+             gf<-schmid(m,nfactors,pc,digits=digits,...)
       Vt <- sum(m)   #find the total variance in the scale
       Vitem <-sum(diag(m)) #
       gload <- gf$sl[,1]
@@ -44,8 +44,9 @@ function(m,nfactors=3,pc="mle",key=NULL,flip=TRUE, digits=NULL,...) {
           }
       gsq <- (sum(gload))^2
       alpha <- ((Vt-Vitem)/Vt)*(nvar/(nvar-1))
-      if (!is.null(digits)) {omega <-list(omega= round(gsq/Vt,digits),alpha=round(alpha,digits),schmid=gf ,key <- key) } else {
-      omega <- list(omega= gsq/Vt,alpha=alpha,schmid=gf,key=key) 
-      return(omega)}
+      if (!is.null(digits)) {omega <-list(omega_h= round(gsq/Vt,digits),alpha=round(alpha,digits),schmid=gf ,key = key) } else {
+      omega <- list(omega_h= gsq/Vt,alpha=alpha,schmid=gf,key=key) }
+      if (plot) {omega.graph(omega,title=title,sl=sl,labels=labels) }
+      return(omega)
       }
 
