@@ -1,8 +1,9 @@
 #corrected estimate of communality, May 21, 2007
 #removed "x" from factanal call, June 14, 2007
 #added ability to do 2 factors by treating them with equal loadings Jan 2008
+#added use of simplimax rotation June 2008
 "schmid" <-
-function (model, nfactors = 3, pc = "pa",  digits=NULL,...) 
+function (model, nfactors = 3, pc = "pa",  digits=2,rotate="oblimin",...) 
 {
  #model is a correlation matrix, or if not, the correlation matrix is found
       #nfactors is the number of factors to extract
@@ -15,10 +16,13 @@ function (model, nfactors = 3, pc = "pa",  digits=NULL,...)
         fact <- factanal(covmat = model, factors = nfactors)
     }}
     orth.load <- loadings(fact)
-       obminfact <- oblimin(orth.load)
+    colnames(orth.load)  <- paste("F",1:nfactors,sep="")
+      if (rotate == "simplimax") {obminfact <- simplimax(orth.load)} else {obminfact <- oblimin(orth.load)}
     rownames(obminfact$loadings) <- attr(model,"dimnames")[[1]]
     fload <- obminfact$loadings
-    factr <- t(obminfact$Th) %*% (obminfact$Th)
+    #factr <- t(obminfact$Th) %*% (obminfact$Th)
+    factr <- obminfact$Phi
+    colnames(factr) <- rownames(factr) <- paste("F",1:nfactors,sep="")
    if (nfactors>2) {
        gfactor <- factanal( covmat = factr, factors = 1)
        gload <- loadings(gfactor) } else {gload<- c(NA,NA)
@@ -28,7 +32,7 @@ function (model, nfactors = 3, pc = "pa",  digits=NULL,...)
               warning("Three factors are required for identification -- general factor loadings set to be equal. Proceed with caution.")}  
 
     gprimaryload <- fload %*% gload
-    colnames(gprimaryload) <- "g factor"
+    colnames(gprimaryload) <- "g"
     u2 <- 1 - diag(orth.load %*% t(orth.load)) 
     h2 <- 1 - u2                         
     uniq <- 1 - fload^2
@@ -36,10 +40,11 @@ function (model, nfactors = 3, pc = "pa",  digits=NULL,...)
     Ig <- matrix(0, ncol = nfactors, nrow = nfactors)
     diag(Ig) <- gload
     primeload <- fload %*% Ig
+
     uniq2 <- 1 - uniq - primeload^2
     sm <- sqrt(uniq2)
-    if (!is.null(digits)) {schmid <- list(sl = cbind(round(gprimaryload,digits), round(sm,digits),round( h2,digits), round(u2,digits)), orthog = round(fact$loadings,digits), oblique = round(fload,digits),
-        fcor = round(factr,digits), gloading = round(gload,digits) )} else {
-    schmid <- list(sl = cbind(gprimaryload, sm, h2, u2), orthog = fact$loadings, oblique = fload, 
-        fcor = factr, gloading = gload)}
+    colnames(sm) <- paste("F",1:nfactors,"*",sep="")
+    if (!is.null(digits)) {schmid <- list(sl = cbind(round(gprimaryload,digits), round(sm,digits),h2=round( h2,digits), u2=round(u2,digits)), orthog = round(orth.load,digits), oblique = round(fload,digits),
+        phi = round(factr,digits), gloading = round(gload,digits) )} else {
+    schmid <- list(sl = cbind(gprimaryload, sm, h2, u2), orthog = fact$loadings, oblique = fload, phi = factr, gloading = gload)}
 }
